expm1f

产品支持情况

  • Ascend 950PR/Ascend 950DT:支持
  • Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
  • Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
  • Atlas 200I/500 A2 推理产品:不支持
  • Atlas 推理系列产品AI Core:不支持
  • Atlas 推理系列产品Vector Core:不支持
  • Atlas 训练系列产品:不支持

功能说明

指定输入x,获取e的x次方减1。

函数原型

inline float expm1f(float x)

参数说明

表1 参数说明

参数名 输入/输出 描述
x 输入 源操作数。

返回值说明

e的x次方减1。

  • 当x为inf时,返回值为inf。
  • 当x为-inf时,返回值为-1.0。
  • 当x为nan时,返回值为nan。

约束说明

针对Ascend 950PR/Ascend 950DT,本接口不支持输入为Subnormal的场景:本接口内部实现使用到了expf,由于expf不支持Subnormal场景,当输入x处于Subnormal范围内时,返回值为0;当x为较大负数且expf的结果处于Subnormal范围内时,本接口最终结果为-1.0。

需要包含的头文件

使用该接口需要包含"simt_api/math_functions.h"头文件。

#include "simt_api/math_functions.h"

调用示例

  • SIMT编程场景:

    __global__ __launch_bounds__(256) void compute_expm1f(float *result, const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = expm1f(x[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    __simt_vf__ __launch_bounds__(256) inline void compute_expm1f_vf(__gm__ float *result, __gm__ const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = expm1f(x[idx]);
    }
    
    __global__ __vector__ void run_expm1f(__gm__ float *result, __gm__ const float *x, uint32_t count)
    {
        asc_vf_call<compute_expm1f_vf>(dim3(256), result, x, count);
    }
    

输入输出示例如下:

x:0.25, 0.75, 1.25, 1.75
result: 0.2840254 1.117 2.490343 4.754602